Welcome to pymaster’s documentation! — pymaster 1.0.2 documentation

# Welcome to pymaster’s documentation!

pymaster is the python implementation of the NaMaster library. The main purpose of this library is to provide support to compute the angular power spectrum of fields defined on a limited region of the sphere using the so-called pseudo-CL formalism.

Below you can find links to pymaster’s full documentation and 8 different example scripts showcasing its usage. Understanding the last script in particular will allow you to make the most efficient use of this module.

We recommend that users read NaMaster’s `scientific documentation` and the C API documentation for a complete overview of all the facilities included in this package, and in order to have a good understanding of the methods implemented in it.

Contents:

- Installation
- Python API documentation
- Example 1: simple pseudo-Cl computation
- Example 2: Bandpowers
- Example 3: Fields
- Example 4: Masks
- Example 5: Using workspaces
- Example 6: Pure E and B
- Example 7: Flat-sky fields
- Example 8: Computing covariance matrices
- Example 9: Rectangular pixels
- Example 10: The Toeplitz approximation
- C API documentation

# Indices and tables

- Index

- Module Index

- Search Page